aboutsummaryrefslogtreecommitdiffstats
path: root/coin/provisioning
diff options
context:
space:
mode:
authorToni Saario <toni.saario@qt.io>2021-03-17 13:00:40 +0200
committerQt Cherry-pick Bot <cherrypick_bot@qt-project.org>2021-04-12 07:21:41 +0000
commit1308663fd65a9d94210bfe34a8df7466a1124bd3 (patch)
tree51fd46be4963d5acfbbf53426c778c53ed4f690b /coin/provisioning
parent0c6dc883e522cf1e7789fcbc9550a9d08a05e6de (diff)
Update windows git version
Older git version does not allow fetching specific revisions. This makes it impossible to fetch the integrations revision of the repository. Change-Id: I513b0d1abb097d139f730ef0cdf2577b9d02e9f8 Reviewed-by: Heikki Halmet <heikki.halmet@qt.io> (cherry picked from commit 7381cbeca87a9f6ede7dd7feee8d9560c31ce3d9) Reviewed-by: Qt Cherry-pick Bot <cherrypick_bot@qt-project.org>
Diffstat (limited to 'coin/provisioning')
-rw-r--r--coin/provisioning/common/windows/install-git.ps18
1 files changed, 4 insertions, 4 deletions
diff --git a/coin/provisioning/common/windows/install-git.ps1 b/coin/provisioning/common/windows/install-git.ps1
index 110c3703..cbdcb587 100644
--- a/coin/provisioning/common/windows/install-git.ps1
+++ b/coin/provisioning/common/windows/install-git.ps1
@@ -32,15 +32,15 @@
#############################################################################
. "$PSScriptRoot\helpers.ps1"
-# Install Git version 2.13.0
+# Install Git version 2.31.0
-$version = "2.13.0"
+$version = "2.31.0"
if (Is64BitWinHost) {
$arch = "-64-bit"
- $sha1 = "E1D7C6E5E16ACAF3C108064A2ED158F604FA29A7"
+ $sha1 = "495d78f8d961e030944d9cb53af80d909d493c3f"
} else {
$arch = "-32-bit"
- $sha1 = "03c7df2e4ef61ea6b6f9c0eb7e6d5151d9682aec"
+ $sha1 = "e57c040aea297b363aefaf26424f2e7a84a4a173"
}
$gitPackage = "C:\Windows\Temp\Git-" + $version + $arch + ".exe"
$url_cache = "\\ci-files01-hki.intra.qt.io\provisioning\windows\Git-" + $version + $arch + ".exe"